@@ -509,9 +509,9 @@ test_that("res_beta_binom", {
   expect_equal(res_beta_binom(0, 1, 0.7), -1.55175565365552)
   expect_equal(res_beta_binom(1, 1, 0.7), 0.844600430900592)
   expect_equal(res_beta_binom(0, 2, 0.5, 0.5), -1.55175564931989)
-  expect_equal(res_beta_binom(1, 2, 0.5, 0.5), 2.1073424255447e-08)
+  expect_equal(res_beta_binom(1, 2, 0.5, 0.5), 0)
   expect_equal(res_beta_binom(0, 2, 0.7, 0.5), -2.01243800222306)
-  expect_equal(res_beta_binom(1, 2, 0.7, 0.5), 0.590513991612016)
+  expect_equal(res_beta_binom(1, 2, 0.7, 0.5), -0.590513991612016)
   expect_identical(res_beta_binom(1, 2, 0.5), 0)
   expect_identical(res_beta_binom(5, 10, 0.5), 0)
   expect_identical(res_beta_binom(1, 2, 0.5, 2), 0)
@@ -533,7 +533,7 @@ test_that("res_beta_binom", {
     )
   )
   expect_equal(res_beta_binom(0, 2, 0.5, type = "dev"), -1.6651092223154)
-  expect_equal(res_beta_binom(0, 2, 0.5, 10, type = "dev"), -1.24912653737637)
+  expect_equal(res_beta_binom(0, 2, 0.5, 10, type = "dev"), -1.24912654086732)
   expect_equal(res_beta_binom(0, 2, 0.5, type = "raw"), -1)
   expect_equal(res_beta_binom(0, 2, 0.5, 10, type = "raw"), -1)
   set.seed(101)
